@@ -2,10 +2,10 @@ from django.conf import settings
 
 from . import defaults
 
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_setting',)
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("get_setting",)
 
 
 def get_setting(setting, override=None):
@@ -20,7 +20,7 @@ def get_setting(setting, override=None):
         None.
     :return: Setting value.
     """
-    attr_name = 'FOBI_{0}'.format(setting)
+    attr_name = "FOBI_{0}".format(setting)
     if hasattr(settings, attr_name):
         return getattr(settings, attr_name)
     else:
