@@ -4,14 +4,14 @@ from .base import get_theme
 from .form_importers import get_form_importer_plugin_urls
 from .helpers import StrippedRequest
 
-__title__ = 'fobi.context_processors'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+__title__ = "fobi.context_processors"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
 __all__ = (
-    'dynamic_values',
-    'form_importers',
-    'theme',
+    "dynamic_values",
+    "form_importers",
+    "theme",
 )
 
 
@@ -21,16 +21,16 @@ def theme(request):
     :param django.http.HttpRequest request:
     :return fobi.base.BaseTheme: Instance of ``fobi.base.BaseTheme``.
     """
-    return {'fobi_theme': get_theme(request, as_instance=True)}
+    return {"fobi_theme": get_theme(request, as_instance=True)}
 
 
 def dynamic_values(request):
     """Dynamic values exposed to public forms."""
     return {
-        'fobi_dynamic_values': {
-            'request': StrippedRequest(request),
-            'now': datetime.datetime.now(),
-            'today': datetime.date.today(),
+        "fobi_dynamic_values": {
+            "request": StrippedRequest(request),
+            "now": datetime.datetime.now(),
+            "today": datetime.date.today(),
         }
     }
 
@@ -38,5 +38,5 @@ def dynamic_values(request):
 def form_importers(request):
     """Form importers."""
     return {
-        'form_importers': get_form_importer_plugin_urls(),
+        "form_importers": get_form_importer_plugin_urls(),
     }
