@@ -6,11 +6,11 @@ from rest_framework.reverse import reverse
 
 from ....models import FormEntry
 
-__title__ = 'fobi.contrib.apps.drf_integration.serializers'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('FormEntrySerializer',)
+__title__ = "fobi.contrib.apps.drf_integration.serializers"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("FormEntrySerializer",)
 
 
 class FormEntrySerializer(serializers.ModelSerializer):
@@ -18,6 +18,7 @@ class FormEntrySerializer(serializers.ModelSerializer):
 
     Used for detail and list views.
     """
+
     url = serializers.SerializerMethodField()
 
     class Meta(object):
@@ -25,24 +26,24 @@ class FormEntrySerializer(serializers.ModelSerializer):
 
         model = FormEntry
         fields = (
-            'url',
-            'id',
-            'slug',
-            'title',
+            "url",
+            "id",
+            "slug",
+            "title",
         )
         read_only_fields = (
-            'url',
-            'id',
-            'slug',
-            'title',
+            "url",
+            "id",
+            "slug",
+            "title",
         )
 
     def get_url(self, obj):
         """Get URL."""
         return reverse(
-            'fobi_form_entry-detail',
+            "fobi_form_entry-detail",
             args=[obj.slug],
-            request=self.context['request']
+            request=self.context["request"],
         )
 
     def get_fields_metadata(self, field_name=None):
