@@ -2,11 +2,11 @@ from django.conf import settings
 
 from . import defaults
 
-__title__ = 'fobi.contrib.plugins.form_elements.content.content_text.conf'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_setting',)
+__title__ = "fobi.contrib.plugins.form_elements.content.content_text.conf"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("get_setting",)
 
 
 def get_setting(setting, override=None):
@@ -25,10 +25,7 @@ def get_setting(setting, override=None):
     """
     if override is not None:
         return override
-    if hasattr(settings, 'FOBI_PLUGIN_CONTENT_TEXT_{0}'.format(setting)):
-        return getattr(
-            settings,
-            'FOBI_PLUGIN_CONTENT_TEXT_{0}'.format(setting)
-        )
+    if hasattr(settings, "FOBI_PLUGIN_CONTENT_TEXT_{0}".format(setting)):
+        return getattr(settings, "FOBI_PLUGIN_CONTENT_TEXT_{0}".format(setting))
     else:
         return getattr(defaults, setting)
