@@ -1,15 +1,15 @@
 from django import forms
 from django.utils.translation import gettext_lazy as _
 
-from fobi.base import BasePluginForm, get_theme
-
 from .settings import DEFAULT_SIZE, SIZES
 
-__title__ = 'fobi.contrib.plugins.form_elements.content.content_video.forms'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('ContentVideoForm',)
+from fobi.base import BasePluginForm, get_theme
+
+__title__ = "fobi.contrib.plugins.form_elements.content.content_video.forms"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("ContentVideoForm",)
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -27,15 +27,15 @@ class ContentVideoForm(forms.Form, BasePluginForm):
         label=_("Title"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     url = forms.CharField(
         label=_("URL"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     size = forms.ChoiceField(
         label=_("Size"),
@@ -43,6 +43,6 @@ class ContentVideoForm(forms.Form, BasePluginForm):
         initial=DEFAULT_SIZE,
         choices=SIZES,
         widget=forms.widgets.Select(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
