@@ -3,11 +3,11 @@ from django.utils.translation import gettext_lazy as _
 
 from fobi.base import BaseFormFieldPluginForm, get_theme
 
-__title__ = 'fobi.contrib.plugins.form_elements.fields.null_boolean.forms'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('NullBooleanSelectForm',)
+__title__ = "fobi.contrib.plugins.form_elements.fields.null_boolean.forms"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("NullBooleanSelectForm",)
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -20,41 +20,41 @@ class NullBooleanSelectForm(forms.Form, BaseFormFieldPluginForm):
         ("name", ""),
         ("help_text", ""),
         ("initial", ""),
-        ("required", False)
+        ("required", False),
     ]
 
     label = forms.CharField(
         label=_("Label"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     name = forms.CharField(
         label=_("Name"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     help_text = forms.CharField(
         label=_("Help text"),
         required=False,
         widget=forms.widgets.Textarea(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     initial = forms.NullBooleanField(
         label=_("Initial"),
         required=False,
         widget=forms.widgets.NullBooleanSelect(
-            attrs={'class': theme.form_element_checkbox_html_class}
-        )
+            attrs={"class": theme.form_element_checkbox_html_class}
+        ),
     )
     required = forms.BooleanField(
         label=_("Required"),
         required=False,
         widget=forms.widgets.CheckboxInput(
-            attrs={'class': theme.form_element_checkbox_html_class}
-        )
+            attrs={"class": theme.form_element_checkbox_html_class}
+        ),
     )
