@@ -4,11 +4,11 @@ from django.utils.translation import gettext_lazy as _
 from fobi.base import BaseFormFieldPluginForm, get_theme
 from fobi.widgets import NumberInput
 
-__title__ = 'fobi.contrib.plugins.form_elements.fields.textarea.forms'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('TextareaForm',)
+__title__ = "fobi.contrib.plugins.form_elements.fields.textarea.forms"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("TextareaForm",)
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -30,48 +30,46 @@ class TextareaForm(forms.Form, BaseFormFieldPluginForm):
         label=_("Label"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     name = forms.CharField(
         label=_("Name"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     help_text = forms.CharField(
         label=_("Help text"),
         required=False,
         widget=forms.widgets.Textarea(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     initial = forms.CharField(
         label=_("Initial"),
         required=False,
         widget=forms.widgets.Textarea(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     required = forms.BooleanField(
         label=_("Required"),
         required=False,
         widget=forms.widgets.CheckboxInput(
-            attrs={'class': theme.form_element_checkbox_html_class}
-        )
+            attrs={"class": theme.form_element_checkbox_html_class}
+        ),
     )
     max_length = forms.IntegerField(
         label=_("Max length"),
         required=False,
-        widget=NumberInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+        widget=NumberInput(attrs={"class": theme.form_element_html_class}),
     )
     placeholder = forms.CharField(
         label=_("Placeholder"),
         required=False,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
