@@ -1,11 +1,12 @@
 from django.conf import settings
 
-__title__ = 'fobi.contrib.plugins.form_elements.security.' \
-            'invisible_recaptcha.conf'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_setting',)
+__title__ = (
+    "fobi.contrib.plugins.form_elements.security." "invisible_recaptcha.conf"
+)
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("get_setting",)
 
 
 def get_setting(setting, override=None):
