@@ -3,12 +3,13 @@ from django.utils.translation import gettext_lazy as _
 
 from fobi.base import BaseFormFieldPluginForm, get_theme
 
-__title__ = 'fobi.contrib.plugins.form_elements.security.' \
-            'invisible_recaptcha.forms'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('InvisibleRecaptchaInputForm',)
+__title__ = (
+    "fobi.contrib.plugins.form_elements.security." "invisible_recaptcha.forms"
+)
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("InvisibleRecaptchaInputForm",)
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -26,20 +27,20 @@ class InvisibleRecaptchaInputForm(forms.Form, BaseFormFieldPluginForm):
         label=_("Label"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     name = forms.CharField(
         label=_("Name"),
         required=True,
         widget=forms.widgets.TextInput(
-            attrs={'class': theme.form_element_html_class}
-        )
+            attrs={"class": theme.form_element_html_class}
+        ),
     )
     required = forms.BooleanField(
         label=_("Required"),
         required=False,
         widget=forms.widgets.CheckboxInput(
-            attrs={'class': theme.form_element_checkbox_html_class}
-        )
+            attrs={"class": theme.form_element_checkbox_html_class}
+        ),
     )
