@@ -1,18 +1,19 @@
 from django.forms.widgets import HiddenInput
 
-from fobi.base import FormElementPluginWidget
-
 from . import UID
 from .conf import get_setting
 
-__title__ = 'fobi.contrib.plugins.form_elements.security.' \
-            'invisible_recaptcha.widgets'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+from fobi.base import FormElementPluginWidget
+
+__title__ = (
+    "fobi.contrib.plugins.form_elements.security." "invisible_recaptcha.widgets"
+)
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
 __all__ = (
-    'InvisibleRecaptchaWidget',
-    'BaseInvisibleRecaptchaWidget',
+    "InvisibleRecaptchaWidget",
+    "BaseInvisibleRecaptchaWidget",
 )
 
 
@@ -37,8 +38,8 @@ class BaseInvisibleRecaptchaWidget(FormElementPluginWidget):
     """Base invisible recaptcha form element plugin widget."""
 
     plugin_uid = UID
-    html_classes = ['invisible-recaptcha']
+    html_classes = ["invisible-recaptcha"]
     media_js = [
-        'https://www.google.com/recaptcha/api.js',
-        'invisible_recaptcha/fobi.plugin.invisible_recaptcha.js',
+        "https://www.google.com/recaptcha/api.js",
+        "invisible_recaptcha/fobi.plugin.invisible_recaptcha.js",
     ]
