@@ -2,20 +2,19 @@
 import logging
 import sys
 
+import six
 # from django.conf import settings
 from django.utils.module_loading import autodiscover_modules
 
-import six
-
 from .conf import get_setting
 
 logger = logging.getLogger(__file__)
 
-__title__ = 'fobi.discover'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('autodiscover',)
+__title__ = "fobi.discover"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("autodiscover",)
 
 
 def autodiscover():
@@ -30,28 +29,24 @@ def autodiscover():
         sys.setrecursionlimit(recursion_limit)
 
     FORM_ELEMENT_PLUGINS_MODULE_NAME = get_setting(
-        'FORM_ELEMENT_PLUGINS_MODULE_NAME'
+        "FORM_ELEMENT_PLUGINS_MODULE_NAME"
     )
     FORM_HANDLER_PLUGINS_MODULE_NAME = get_setting(
-        'FORM_HANDLER_PLUGINS_MODULE_NAME'
-    )
-    THEMES_MODULE_NAME = get_setting(
-        'THEMES_MODULE_NAME'
-    )
-    FORM_CALLBACKS_MODULE_NAME = get_setting(
-        'FORM_CALLBACKS_MODULE_NAME'
+        "FORM_HANDLER_PLUGINS_MODULE_NAME"
     )
+    THEMES_MODULE_NAME = get_setting("THEMES_MODULE_NAME")
+    FORM_CALLBACKS_MODULE_NAME = get_setting("FORM_CALLBACKS_MODULE_NAME")
 
     INTEGRATION_FORM_ELEMENT_PLUGINS_MODULE_NAME = get_setting(
-        'INTEGRATION_FORM_ELEMENT_PLUGINS_MODULE_NAME'
+        "INTEGRATION_FORM_ELEMENT_PLUGINS_MODULE_NAME"
     )
 
     INTEGRATION_FORM_HANDLER_PLUGINS_MODULE_NAME = get_setting(
-        'INTEGRATION_FORM_HANDLER_PLUGINS_MODULE_NAME'
+        "INTEGRATION_FORM_HANDLER_PLUGINS_MODULE_NAME"
     )
 
     FORM_IMPORTER_PLUGINS_MODULE_NAME = get_setting(
-        'FORM_IMPORTER_PLUGINS_MODULE_NAME'
+        "FORM_IMPORTER_PLUGINS_MODULE_NAME"
     )
 
     # Discover modules
