@@ -4,24 +4,22 @@ from django.forms.forms import BaseForm
 from django.forms.widgets import media_property
 from django.http import HttpResponseRedirect
 from django.urls import reverse
-
 from formtools.wizard.views import (
     CookieWizardView,
     SessionWizardView,
     WizardView,
 )
-
 from six import with_metaclass
 
 from .constants import WIZARD_TYPE_COOKIE, WIZARD_TYPE_SESSION
 
-__title__ = 'fobi.dynamic'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+__title__ = "fobi.dynamic"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
 __all__ = (
-    'assemble_form_class',
-    'assemble_form_wizard_class',
+    "assemble_form_class",
+    "assemble_form_wizard_class",
 )
 
 # ****************************************************************************
@@ -31,14 +29,16 @@ __all__ = (
 # ****************************************************************************
 
 
-def assemble_form_class(form_entry,
-                        base_class=BaseForm,
-                        request=None,
-                        origin=None,
-                        origin_kwargs_update_func=None,
-                        origin_return_func=None,
-                        form_element_entries=None,
-                        get_form_field_instances_kwargs={}):
+def assemble_form_class(
+    form_entry,
+    base_class=BaseForm,
+    request=None,
+    origin=None,
+    origin_kwargs_update_func=None,
+    origin_return_func=None,
+    form_element_entries=None,
+    get_form_field_instances_kwargs={},
+):
     """Assemble a form class by given entry.
 
     :param form_entry:
@@ -69,38 +69,42 @@ def assemble_form_class(form_entry,
             """New."""
             base_fields = []
 
-            for creation_counter, form_element_entry \
-                    in enumerate(form_element_entries):
+            for creation_counter, form_element_entry in enumerate(
+                form_element_entries
+            ):
                 plugin = form_element_entry.get_plugin(request=request)
 
                 # We simply make sure the plugin exists. We don't handle
                 # exceptions relate to the non-existent plugins here. They
                 # are instead handled in registry.
                 if plugin:
-                    plugin_form_field_instances = \
+                    plugin_form_field_instances = (
                         plugin._get_form_field_instances(
                             form_element_entry=form_element_entry,
                             origin=origin,
                             kwargs_update_func=origin_kwargs_update_func,
                             return_func=origin_return_func,
-                            extra={'counter': creation_counter},
+                            extra={"counter": creation_counter},
                             request=request,
                             form_entry=form_entry,
                             form_element_entries=form_element_entries,
-                            **get_form_field_instances_kwargs
+                            **get_form_field_instances_kwargs,
                         )
-                    for form_field_name, form_field_instance \
-                            in plugin_form_field_instances:
+                    )
+                    for (
+                        form_field_name,
+                        form_field_instance,
+                    ) in plugin_form_field_instances:
                         base_fields.append(
                             (form_field_name, form_field_instance)
                         )
 
-            attrs['base_fields'] = OrderedDict(base_fields)
+            attrs["base_fields"] = OrderedDict(base_fields)
             new_class = super(DeclarativeFieldsMetaclass, cls).__new__(
                 cls, name, bases, attrs
             )
 
-            if 'media' not in attrs:
+            if "media" not in attrs:
                 new_class.media = media_property(new_class)
 
             return new_class
@@ -113,14 +117,16 @@ def assemble_form_class(form_entry,
     return DynamicForm
 
 
-def assemble_form_wizard_class(form_wizard_entry,
-                               base_class=SessionWizardView,
-                               request=None,
-                               origin=None,
-                               origin_kwargs_update_func=None,
-                               origin_return_func=None,
-                               form_wizard_form_entries=None,
-                               template_name=None):
+def assemble_form_wizard_class(
+    form_wizard_entry,
+    base_class=SessionWizardView,
+    request=None,
+    origin=None,
+    origin_kwargs_update_func=None,
+    origin_return_func=None,
+    form_wizard_form_entries=None,
+    template_name=None,
+):
     """Assemble form wizard class.
 
     :param form_wizard_entry:
@@ -144,14 +150,12 @@ def assemble_form_wizard_class(form_wizard_entry,
     if form_wizard_form_entries is None:
         form_entries = [
             form_wizard_form_entry.form_entry
-            for form_wizard_form_entry
-            in form_wizard_entry.formwizardformentry_set.all()
+            for form_wizard_form_entry in form_wizard_entry.formwizardformentry_set.all()
         ]
     else:
         form_entries = [
             form_wizard_form_entry.form_entry
-            for form_wizard_form_entry
-            in form_wizard_form_entries
+            for form_wizard_form_entry in form_wizard_form_entries
         ]
 
     # DeclarativeFormsMetaclass
@@ -182,20 +186,14 @@ def assemble_form_wizard_class(form_wizard_entry,
             """
             form_list = []
 
-            for creation_counter, form_entry \
-                    in enumerate(form_entries):
+            for creation_counter, form_entry in enumerate(form_entries):
 
-                form_cls = assemble_form_class(
-                    form_entry,
-                    request=request
-                )
+                form_cls = assemble_form_class(form_entry, request=request)
 
-                form_list.append(
-                    (form_entry.slug, form_cls)
-                )
+                form_list.append((form_entry.slug, form_cls))
 
-            attrs['form_list'] = form_list
-            attrs['template_name'] = template_name
+            attrs["form_list"] = form_list
+            attrs["template_name"] = template_name
             new_class = super(DeclarativeFormsMetaclass, cls).__new__(
                 cls, name, bases, attrs
             )
@@ -206,15 +204,17 @@ def assemble_form_wizard_class(form_wizard_entry,
             return new_class
 
     # DynamicFormWizard
-    class DynamicFormWizard(with_metaclass(
-            DeclarativeFormsMetaclass, base_class)):
+    class DynamicFormWizard(
+        with_metaclass(DeclarativeFormsMetaclass, base_class)
+    ):
         """Dynamically created form wizard class."""
 
         def done(self, form_list, **kwargs):
             """Done."""
             # do_something_with_the_form_data(form_list)
-            redirect_url = reverse('fobi.form_wizard_entry_submitted',
-                                   [form_wizard_entry.slug])
+            redirect_url = reverse(
+                "fobi.form_wizard_entry_submitted", [form_wizard_entry.slug]
+            )
             return HttpResponseRedirect(redirect_url)
 
     # Finally, return the dynamic wizard
