@@ -1,24 +1,24 @@
-__title__ = 'fobi.exceptions'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+__title__ = "fobi.exceptions"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
 __all__ = (
-    'BaseException',
-    'DoesNotExist',
-    'FormCallbackError',
-    'FormElementPluginDoesNotExist',
-    'FormElementPluginError',
-    'FormHandlerPluginDoesNotExist',
-    'FormHandlerPluginError',
-    'FormPluginError',
-    'FormWizardHandlerPluginDoesNotExist',
-    'ImproperlyConfigured',
-    'IntegrationFormElementPluginDoesNotExist',
-    'IntegrationFormHandlerPluginDoesNotExist',
-    'InvalidRegistryItemType',
-    'NoDefaultThemeSet',
-    'PluginDoesNotExist',
-    'ThemeDoesNotExist',
+    "BaseException",
+    "DoesNotExist",
+    "FormCallbackError",
+    "FormElementPluginDoesNotExist",
+    "FormElementPluginError",
+    "FormHandlerPluginDoesNotExist",
+    "FormHandlerPluginError",
+    "FormPluginError",
+    "FormWizardHandlerPluginDoesNotExist",
+    "ImproperlyConfigured",
+    "IntegrationFormElementPluginDoesNotExist",
+    "IntegrationFormHandlerPluginDoesNotExist",
+    "InvalidRegistryItemType",
+    "NoDefaultThemeSet",
+    "PluginDoesNotExist",
+    "ThemeDoesNotExist",
 )
 
 
