@@ -1,10 +1,10 @@
 from ..base import get_theme
 
-__title__ = 'fobi.integration.helpers'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_template_choices',)
+__title__ = "fobi.integration.helpers"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("get_template_choices",)
 
 
 def get_template_choices(source, choices, theme_specific_choices_key):
