@@ -1,7 +1,5 @@
 from django.core.management.base import BaseCommand
 
-from django_nine import versions
-
 from fobi.utils import sync_plugins
 
 
@@ -15,16 +13,15 @@ class Command(BaseCommand):
         - ``fobi.models.FormHandlerPlugin``
     """
 
-    if versions.DJANGO_GTE_2_0:
-        def add_arguments(self, parser):
-            parser.add_argument(
-                '--noinput',
-                '--no-input',
-                action='store_false',
-                dest='interactive',
-                help='Tells Django to NOT prompt the user for input of any '
-                     'kind.',
-            )
+    def add_arguments(self, parser):
+        parser.add_argument(
+            "--noinput",
+            "--no-input",
+            action="store_false",
+            dest="interactive",
+            help="Tells Django to NOT prompt the user for input of any "
+            "kind.",
+        )
 
     def handle(self, *args, **options):
         """Handle."""
