@@ -3,9 +3,8 @@ from django.core.management.base import BaseCommand
 from fobi.models import (
     FormElementEntry,
     FormHandlerEntry,
-    FormWizardHandlerEntry
+    FormWizardHandlerEntry,
 )
-
 from fobi.utils import update_plugin_data_for_entries
 
 
@@ -26,6 +25,7 @@ class Command(BaseCommand):
         form_handler_entries = FormHandlerEntry._default_manager.all()
         update_plugin_data_for_entries(entries=form_handler_entries)
 
-        form_wizard_handler_entries = FormWizardHandlerEntry \
-            ._default_manager.all()
+        form_wizard_handler_entries = (
+            FormWizardHandlerEntry._default_manager.all()
+        )
         update_plugin_data_for_entries(entries=form_wizard_handler_entries)
