@@ -1,25 +1,25 @@
 from django import forms
 from django.conf import settings
 from django.forms.utils import ErrorDict
-from django.template import Library, TemplateSyntaxError, Node
+from django.template import Library, Node, TemplateSyntaxError
 from django.utils.translation import gettext_lazy as _
 
 from ..base import get_theme
 from ..settings import DISPLAY_AUTH_LINK
 
-__title__ = 'fobi.templatetags.fobi_tags'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+__title__ = "fobi.templatetags.fobi_tags"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
 __all__ = (
-    'get_fobi_form_handler_plugin_custom_actions',
-    'get_fobi_form_wizard_handler_plugin_custom_actions',
-    'get_fobi_plugin',
-    'get_form_field_type',
-    'get_form_hidden_fields_errors',
-    'has_edit_form_entry_permissions',
-    'render_auth_link',
-    'render_fobi_forms_list',
+    "get_fobi_form_handler_plugin_custom_actions",
+    "get_fobi_form_wizard_handler_plugin_custom_actions",
+    "get_fobi_plugin",
+    "get_form_field_type",
+    "get_form_hidden_fields_errors",
+    "has_edit_form_entry_permissions",
+    "render_auth_link",
+    "render_fobi_forms_list",
 )
 
 THEME = get_theme(request=None, as_instance=True)
@@ -49,12 +49,12 @@ class GetFobiPluginNode(Node):
 
     def render(self, context):
         """Render."""
-        request = context['request']
+        request = context["request"]
         entry = self.entry.resolve(context, True)
 
         plugin = entry.get_plugin(request=request)
         context[self.as_var] = plugin
-        return ''
+        return ""
 
 
 @register.tag
@@ -78,12 +78,10 @@ def get_fobi_plugin(parser, token):
     bits = token.contents.split()
 
     if len(bits) == 4:
-        if bits[-2] != 'as':
+        if bits[-2] != "as":
             raise TemplateSyntaxError(
                 "Invalid syntax for {0}. Incorrect number of "
-                "arguments.".format(
-                    bits[0]
-                )
+                "arguments.".format(bits[0])
             )
         as_var = bits[-1]
     else:
@@ -96,6 +94,7 @@ def get_fobi_plugin(parser, token):
 
     return GetFobiPluginNode(entry=entry, as_var=as_var)
 
+
 # *****************************************************************************
 # ********************** Form handler plugin specific *************************
 # *****************************************************************************
@@ -112,12 +111,12 @@ class GetFobiFormHandlerPluginCustomActionsNode(Node):
 
     def render(self, context):
         """Render."""
-        request = context['request']
+        request = context["request"]
         plugin = self.plugin.resolve(context, True)
         form_entry = self.form_entry.resolve(context, True)
 
         context[self.as_var] = plugin.get_custom_actions(form_entry, request)
-        return ''
+        return ""
 
 
 @register.tag
@@ -140,12 +139,10 @@ def get_fobi_form_handler_plugin_custom_actions(parser, token):
     bits = token.contents.split()
 
     if len(bits) == 5:
-        if bits[-2] != 'as':
+        if bits[-2] != "as":
             raise TemplateSyntaxError(
                 "Invalid syntax for {0}. Incorrect number of "
-                "arguments.".format(
-                    bits[0]
-                )
+                "arguments.".format(bits[0])
             )
         as_var = bits[-1]
     else:
@@ -161,6 +158,7 @@ def get_fobi_form_handler_plugin_custom_actions(parser, token):
         plugin=plugin, form_entry=form_entry, as_var=as_var
     )
 
+
 # *****************************************************************************
 # ******************* Form wizard handler plugin specific *********************
 # *****************************************************************************
@@ -177,13 +175,14 @@ class GetFobiFormWizardHandlerPluginCustomActionsNode(Node):
 
     def render(self, context):
         """Render."""
-        request = context['request']
+        request = context["request"]
         plugin = self.plugin.resolve(context, True)
         form_wizard_entry = self.form_wizard_entry.resolve(context, True)
 
-        context[self.as_var] = plugin.get_custom_actions(form_wizard_entry,
-                                                         request)
-        return ''
+        context[self.as_var] = plugin.get_custom_actions(
+            form_wizard_entry, request
+        )
+        return ""
 
 
 @register.tag
@@ -207,12 +206,10 @@ def get_fobi_form_wizard_handler_plugin_custom_actions(parser, token):
     bits = token.contents.split()
 
     if len(bits) == 5:
-        if bits[-2] != 'as':
+        if bits[-2] != "as":
             raise TemplateSyntaxError(
                 "Invalid syntax for {0}. Incorrect number of "
-                "arguments.".format(
-                    bits[0]
-                )
+                "arguments.".format(bits[0])
             )
         as_var = bits[-1]
     else:
@@ -228,6 +225,7 @@ def get_fobi_form_wizard_handler_plugin_custom_actions(parser, token):
         plugin=plugin, form_wizard_entry=form_wizard_entry, as_var=as_var
     )
 
+
 # *****************************************************************************
 # *****************************************************************************
 # *****************************************************************************
@@ -242,37 +240,37 @@ def render_auth_link(context):
     if not DISPLAY_AUTH_LINK:
         return {}
 
-    request = context.get('request', None)
+    request = context.get("request", None)
     user_is_authenticated = request.user.is_authenticated
 
     if request and user_is_authenticated:
         try:
             auth_url = settings.LOGOUT_URL
-            auth_icon_class = 'icon-signout'
-            auth_link_text = _('Log out')
+            auth_icon_class = "icon-signout"
+            auth_link_text = _("Log out")
         except Exception:
-            auth_url = ''
-            auth_icon_class = ''
-            auth_link_text = ''
+            auth_url = ""
+            auth_icon_class = ""
+            auth_link_text = ""
     else:
         try:
             auth_url = settings.LOGIN_URL
-            auth_icon_class = 'icon-signin'
-            auth_link_text = _('Log in')
+            auth_icon_class = "icon-signin"
+            auth_link_text = _("Log in")
         except Exception:
-            auth_url = ''
-            auth_icon_class = ''
-            auth_link_text = ''
+            auth_url = ""
+            auth_icon_class = ""
+            auth_link_text = ""
 
     return {
-        'auth_link': auth_url,
-        'auth_icon_class': auth_icon_class,
-        'auth_link_text': auth_link_text
+        "auth_link": auth_url,
+        "auth_icon_class": auth_icon_class,
+        "auth_link_text": auth_link_text,
     }
 
 
 register.inclusion_tag(
-    'fobi/snippets/render_auth_link.html', takes_context=True
+    "fobi/snippets/render_auth_link.html", takes_context=True
 )(render_auth_link)
 
 
@@ -292,17 +290,17 @@ def render_fobi_forms_list(context, queryset, *args, **kwargs):
                                            show_delete_link=False \
                                            show_export_link=False %}
     """
-    request = context.get('request', None)
-    show_edit_link = kwargs.get('edit_link', False)
-    show_delete_link = kwargs.get('delete_link', False)
-    show_export_link = kwargs.get('export_link', False)
+    request = context.get("request", None)
+    show_edit_link = kwargs.get("edit_link", False)
+    show_delete_link = kwargs.get("delete_link", False)
+    show_export_link = kwargs.get("export_link", False)
     return {
-        'show_custom_actions': (
+        "show_custom_actions": (
             show_edit_link or show_delete_link or show_export_link
         ),
-        'show_edit_link': show_edit_link,
-        'show_delete_link': show_delete_link,
-        'show_export_link': show_export_link,
+        "show_edit_link": show_edit_link,
+        "show_delete_link": show_delete_link,
+        "show_export_link": show_export_link,
     }
 
 
@@ -325,39 +323,37 @@ class HasEditFormEntryPermissionsNode(Node):
     def render(self, context):
         """Render."""
         try:
-            perms = context['perms']
+            perms = context["perms"]
         except Exception as err:
             if self.as_var:
                 context[self.as_var] = False
-                return ''
+                return ""
             else:
                 return False
 
         perms_required = [
-            'fobi.add_formentry',
-            'fobi.change_formentry',
-            'fobi.delete_formentry',
-
-            'fobi.add_formelemententry',
-            'fobi.change_formelemententry',
-            'fobi.delete_formelemententry',
-
-            'fobi.add_formhandlerentry',
-            'fobi.change_formhandlerentry',
-            'fobi.delete_formhandlerentry',
+            "fobi.add_formentry",
+            "fobi.change_formentry",
+            "fobi.delete_formentry",
+            "fobi.add_formelemententry",
+            "fobi.change_formelemententry",
+            "fobi.delete_formelemententry",
+            "fobi.add_formhandlerentry",
+            "fobi.change_formhandlerentry",
+            "fobi.delete_formhandlerentry",
         ]
 
         for perm in perms_required:
             if perm in perms:
                 if self.as_var:
                     context[self.as_var] = True
-                    return ''
+                    return ""
                 else:
                     return True
 
         if self.as_var:
             context[self.as_var] = False
-            return ''
+            return ""
         else:
             return False
 
@@ -395,6 +391,7 @@ def has_edit_form_entry_permissions(parser, token):
 
     return HasEditFormEntryPermissionsNode(as_var=as_var)
 
+
 # *****************************************************************************
 # *****************************************************************************
 # *****************************************************************************
@@ -438,18 +435,18 @@ class GetFormFieldTypeNode(Node):
         properties = []
 
         if isinstance(field.field.widget, forms.CheckboxInput):
-            properties.append('is_checkbox')
+            properties.append("is_checkbox")
 
         if isinstance(field.field.widget, forms.CheckboxSelectMultiple):
-            properties.append('is_checkbox_multiple')
+            properties.append("is_checkbox_multiple")
 
         if isinstance(field.field.widget, forms.RadioSelect):
-            properties.append('is_radio')
+            properties.append("is_radio")
 
         res = FormFieldType(properties)
 
         context[self.as_var] = res
-        return ''
+        return ""
 
 
 @register.tag
@@ -470,12 +467,10 @@ def get_form_field_type(parser, token):
     bits = token.contents.split()
 
     if len(bits) == 4:
-        if bits[-2] != 'as':
+        if bits[-2] != "as":
             raise TemplateSyntaxError(
                 "Invalid syntax for {0}. Incorrect number of "
-                "arguments.".format(
-                    bits[0]
-                )
+                "arguments.".format(bits[0])
             )
         as_var = bits[-1]
     else:
@@ -508,7 +503,7 @@ class GetFormHiddenFieldsErrorsNode(Node):
                 hidden_fields_errors.update({field.name: field.errors})
 
         context[self.as_var] = hidden_fields_errors
-        return ''
+        return ""
 
 
 @register.tag
@@ -527,12 +522,10 @@ def get_form_hidden_fields_errors(parser, token):
     bits = token.contents.split()
 
     if len(bits) == 4:
-        if bits[-2] != 'as':
+        if bits[-2] != "as":
             raise TemplateSyntaxError(
                 "Invalid syntax for {0}. Incorrect number of "
-                "arguments.".format(
-                    bits[0]
-                )
+                "arguments.".format(bits[0])
             )
         as_var = bits[-1]
     else:
