@@ -1,31 +1,25 @@
-import gc
 import logging
+import os
+from datetime import datetime
 
+from django.conf import settings
+from django.contrib.staticfiles.testing import StaticLiveServerTestCase
+from django.core.management import call_command
+from django.urls import reverse
 from selenium import webdriver
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.firefox.firefox_binary import FirefoxBinary
 from selenium.webdriver.support.wait import WebDriverWait
 
-from django.core.management import call_command
-from django.urls import reverse
-from django.conf import settings
-from django.contrib.staticfiles.testing import StaticLiveServerTestCase
-
 from . import constants
-from .helpers import (
-    setup_app,
-    get_or_create_admin_user,
-    phantom_js_clean_up,
-)
+from .helpers import get_or_create_admin_user, phantom_js_clean_up, setup_app
 
-__title__ = 'fobi.tests.test_browser_build_dynamic_forms'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = (
-    'BaseFobiBrowserBuldDynamicFormsTest',
-)
+__title__ = "fobi.tests.test_browser_build_dynamic_forms"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("BaseFobiBrowserBuldDynamicFormsTest",)
 
 logger = logging.getLogger(__name__)
 
@@ -52,35 +46,30 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
     def tearDown(self):
         """Tear down."""
         super(BaseFobiBrowserBuldDynamicFormsTest, self).tearDown()
-        call_command('flush',
-                     verbosity=0,
-                     interactive=False,
-                     reset_sequences=True,
-                     allow_cascade=True,
-                     inhibit_post_migrate=False)
-        # gc.collect()
+        call_command(
+            "flush",
+            verbosity=0,
+            interactive=False,
+            reset_sequences=True,
+            allow_cascade=True,
+            inhibit_post_migrate=False,
+        )
 
     @classmethod
     def setUpClass(cls):
         """Set up class."""
         chrome_driver_path = getattr(
-            settings,
-            'CHROME_DRIVER_EXECUTABLE_PATH',
-            None
+            settings, "CHROME_DRIVER_EXECUTABLE_PATH", None
         )
-        chrome_driver_options = getattr(
-            settings,
-            'CHROME_DRIVER_OPTIONS',
-            None
-        )
-        firefox_bin_path = getattr(settings, 'FIREFOX_BIN_PATH', None)
+        chrome_driver_options = getattr(settings, "CHROME_DRIVER_OPTIONS", None)
+        firefox_bin_path = getattr(settings, "FIREFOX_BIN_PATH", None)
         phantom_js_executable_path = getattr(
-            settings, 'PHANTOM_JS_EXECUTABLE_PATH', None
+            settings, "PHANTOM_JS_EXECUTABLE_PATH", None
         )
         if chrome_driver_path is not None:
             cls.driver = webdriver.Chrome(
                 executable_path=chrome_driver_path,
-                options=chrome_driver_options
+                options=chrome_driver_options,
             )
         elif phantom_js_executable_path is not None:
             if phantom_js_executable_path:
@@ -111,13 +100,14 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
             print(err)
 
         super(BaseFobiBrowserBuldDynamicFormsTest, cls).tearDownClass()
-        call_command('flush',
-                     verbosity=0,
-                     interactive=False,
-                     reset_sequences=True,
-                     allow_cascade=True,
-                     inhibit_post_migrate=False)
-        # gc.collect()
+        call_command(
+            "flush",
+            verbosity=0,
+            interactive=False,
+            reset_sequences=True,
+            allow_cascade=True,
+            inhibit_post_migrate=False,
+        )
 
     # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -138,9 +128,11 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
 
     def _get_live_server_url(self):
         """Get live server URL."""
-        return self.LIVE_SERVER_URL \
-            if self.LIVE_SERVER_URL \
+        return (
+            self.LIVE_SERVER_URL
+            if self.LIVE_SERVER_URL
             else self.live_server_url
+        )
 
     def _authenticate(self):
         """Authenticate."""
@@ -148,10 +140,7 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
         user = get_or_create_admin_user()
 
         self.driver.get(
-            '{0}{1}'.format(
-                self._get_live_server_url(),
-                reverse('auth_login')
-            )
+            "{0}{1}".format(self._get_live_server_url(), reverse("auth_login"))
         )
         self._maximize_window()
         username_input = self.driver.find_element_by_name("username")
@@ -179,7 +168,7 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
 
     def _aggressive_click(self, element):
         """Aggressive click."""
-        link = element.get_attribute('href')
+        link = element.get_attribute("href")
         self.driver.get(link)
 
     def _scroll_to_element(self, form_element, simple=False):
@@ -188,14 +177,10 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
         if simple:
             return
 
-        x = coordinates.get('x', 0)
-        y = coordinates.get('y', 0)
-        self.driver.execute_script(
-            "window.scrollTo({0}, {1});".format(x, y)
-        )
-        self.driver.execute_script(
-            "window.scrollBy({0}, {1});".format(0, -100)
-        )
+        x = coordinates.get("x", 0)
+        y = coordinates.get("y", 0)
+        self.driver.execute_script("window.scrollTo({0}, {1});".format(x, y))
+        self.driver.execute_script("window.scrollBy({0}, {1});".format(0, -100))
 
     def _move_to_element(self, form_element, simple=False):
         """Move to element."""
@@ -203,22 +188,25 @@ class BaseFobiBrowserBuldDynamicFormsTest(StaticLiveServerTestCase):
 
     def _scroll_to(self, x, y):
         """Scroll to."""
-        self.driver.execute_script(
-            "window.scrollTo({0}, {1});".format(x, y)
-        )
+        self.driver.execute_script("window.scrollTo({0}, {1});".format(x, y))
 
     def _scroll_by(self, x, y):
         """Scroll by."""
-        self.driver.execute_script(
-            "window.scrollBy({0}, {1});".format(x, y)
-        )
+        self.driver.execute_script("window.scrollBy({0}, {1});".format(x, y))
 
     def _scroll_page_top(self):
         """Scroll to the page top."""
-        html = self.driver.find_element_by_tag_name('html')
+        html = self.driver.find_element_by_tag_name("html")
         html.send_keys(Keys.HOME)
 
     def _scroll_page_bottom(self):
         """Scroll to the page bottom."""
-        html = self.driver.find_element_by_tag_name('html')
+        html = self.driver.find_element_by_tag_name("html")
         html.send_keys(Keys.END)
+
+    def take_screenshot(self, name="screenshot"):
+        now = datetime.now().strftime("%Y-%m-%d_%H-%M-%S")
+        filename = os.path.join(settings.STATIC_ROOT, f"{name}-{now}.png")
+        self.driver.get_screenshot_as_file(filename)
+        logger.debug(f"Screenshot saved in: {filename}")
+        return filename
