@@ -3,19 +3,20 @@ import unittest
 # from django.contrib.auth import get_user_model
 from django.test import TestCase
 
-from fobi.contrib.plugins.form_importers \
-         .mailchimp_importer.fobi_form_importers import MailChimpImporter
-from fobi.models import FormEntry, FormElementEntry
-
 from .core import print_info
 from .data import TEST_MAILCHIMP_IMPORTER_FORM_DATA
-from .helpers import setup_app, get_or_create_admin_user
+from .helpers import get_or_create_admin_user, setup_app
 
-__title__ = 'fobi.tests.test_form_importers_mailchimp'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = '2014-2019 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('FormImportersMailchimpTest',)
+from fobi.contrib.plugins.form_importers.mailchimp_importer.fobi_form_importers import (
+    MailChimpImporter,
+)
+from fobi.models import FormElementEntry, FormEntry
+
+__title__ = "fobi.tests.test_form_importers_mailchimp"
+__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
+__copyright__ = "2014-2019 Artur Barseghyan"
+__license__ = "GPL 2.0/LGPL 2.1"
+__all__ = ("FormImportersMailchimpTest",)
 
 
 class FormImportersMailchimpTest(TestCase):
@@ -30,19 +31,15 @@ class FormImportersMailchimpTest(TestCase):
         """Test mailchimp importer."""
         user = get_or_create_admin_user()
 
-        form_properties = {
-            'name': 'Test mailchimp form',
-            'user': user
-        }
+        form_properties = {"name": "Test mailchimp form", "user": user}
 
         importer = MailChimpImporter(
-            form_entry_cls=FormEntry,
-            form_element_entry_cls=FormElementEntry
+            form_entry_cls=FormEntry, form_element_entry_cls=FormElementEntry
         )
 
         importer.import_data(
             form_properties=form_properties,
-            form_data=TEST_MAILCHIMP_IMPORTER_FORM_DATA
+            form_data=TEST_MAILCHIMP_IMPORTER_FORM_DATA,
         )
 
         form_entry = FormEntry.objects.get(**form_properties)
@@ -50,5 +47,5 @@ class FormImportersMailchimpTest(TestCase):
         self.assertIsNotNone(form_entry.pk)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
